==> qcobjects-2.1.341.jar: META-INF/resources/webjars/qcobjects/2.1.341/AUTHOR.md <==
![jeanmachuca](https://qcobjects.dev/doc/img/jeanmachuca.png)

# About the author:

  - Jean Machuca is the author of QCObjects and he has over 20 years of experience doing software
in different programming languages for banking, health, retail and advertising industries.

## A brief of the story of Jean and his purpose:

He published the first commit of QCObjects in 2015 focusing its development
in quality over quantity.
The main goal of Jean doing QCObjects was to be happy while coding the lots of custom software for the customers of QuickCorp, its own company since 2014.
To read ilegible code is very frustrating and unhappy. To avoid this, Jean created a framework to code fancy, clean and quick using a single technology for backend and front-end together, and he did it based in the most used language of the world (JavaScript).

QCObjects was introduced to the world's market in July of 2019 in the RISE Conference, the largest tech conference of Asia, and it was been exhibited in the Web Summit on Lisbon 2019, the best technology conference on the planet. [QCObjects is being featured by British Herald as today, the most advanced framework for modern software development.](https://britishherald.com/qcobjects-the-first-world-class-tech-framework-made-in-south-america-is-meant-to-make-developers-happier-while-they-code/)

Now, almost anyone in the world can use QCObjects to develop almost any kind of end to end solutions, and they can quick start in just one step.

Jean's dream is to become QCObjects into the next-generation tool for software development

==> qcobjects-2.3.22.jar: META-INF/resources/webjars/qcobjects/2.3.22/AUTHOR.md <==
![jeanmachuca](https://qcobjects.dev/doc/img/jeanmachuca.png)

# About the author:

  - Jean Machuca is the author of QCObjects and he has over 20 years of experience doing software
in different programming languages for banking, health, retail and advertising industries.

## A brief of the story of Jean and his purpose:

He published the first commit of QCObjects in 2015 focusing its development
in quality over quantity.
The main goal of Jean doing QCObjects was to be happy while coding the lots of custom software for the customers of QuickCorp, its own company since 2014.
To read ilegible code is very frustrating and unhappy. To avoid this, Jean created a framework to code fancy, clean and quick using a single technology for backend and front-end together, and he did it based in the most used language of the world (JavaScript).

QCObjects was introduced to the world's market in July of 2019 in the RISE Conference, the largest tech conference of Asia, and it was been exhibited in the Web Summit on Lisbon 2019, the best technology conference on the planet. [QCObjects is being featured by British Herald as today, the most advanced framework for modern software development.](https://britishherald.com/qcobjects-the-first-world-class-tech-framework-made-in-south-america-is-meant-to-make-developers-happier-while-they-code/)

Now, almost anyone in the world can use QCObjects to develop almost any kind of end to end solutions, and they can quick start in just one step.

Jean's dream is to become QCObjects into the next-generation tool for software development

You want to know more about Jean? Meet him in person here in a [video chat](https://superpeer.com/qcobjects)
